package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.MarketStock;

/**
 * 市场大盘（日）Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-20
 */
public interface MarketStockMapper 
{
    /**
     * 查询市场大盘（日）
     * 
     * @param id 市场大盘（日）主键
     * @return 市场大盘（日）
     */
    public MarketStock selectMarketStockById(Integer id);

    /**
     * 查询市场大盘（日）列表
     * 
     * @param marketStock 市场大盘（日）
     * @return 市场大盘（日）集合
     */
    public List<MarketStock> selectMarketStockList(MarketStock marketStock);

    /**
     * 新增市场大盘（日）
     * 
     * @param marketStock 市场大盘（日）
     * @return 结果
     */
    public int insertMarketStock(MarketStock marketStock);

    /**
     * 修改市场大盘（日）
     * 
     * @param marketStock 市场大盘（日）
     * @return 结果
     */
    public int updateMarketStock(MarketStock marketStock);

    /**
     * 删除市场大盘（日）
     * 
     * @param id 市场大盘（日）主键
     * @return 结果
     */
    public int deleteMarketStockById(Integer id);

    /**
     * 批量删除市场大盘（日）
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMarketStockByIds(Integer[] ids);
}
